package com.knauf.ejb.kuchenzutatbmp;

import java.util.ArrayList;
import javax.ejb.EJBLocalObject;

/**
 * Local-Interface der Kuchen-Bean.
 * Enthlt nur die Methoden zum Setzen der Properties.
 * Darf kein Remote-Home-Interface sein, da in beide Richtungen (von Kuchen zu Zutat und
 * von Zutat zu Kuchen) referenziert werden kann.
 * 
 * @author  Wolfgang Knauf
 * @version 1.0
 */

public interface LocalKuchenBMP extends EJBLocalObject
{
  /**Abrufen der Kuchen-ID.
   * Es gibt keine Set-Methode dazu (weil es das PrimaryKey-Feld ist).
   * @return Die Kuchen-ID.
   */
  public Long getId();

  /**Abrufen des Kuchen-Namens.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public String getName();

  /**Setzen des Kuchen-Namens.
   * @param str_Name Neuer Name.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public void setName (String str_Name);

  /**Abrufen aller Zutaten dieses Kuchens.
   * Da hier mit BeanManagedPersistence gearbeitet wird, wird die Liste manuell als Liste von LocalInterfaces
   * erzeugt.
   * @return Collection von Zutat-Objekten.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public ArrayList getZutatenListe();

  /**Hinzufgen einer Zutat zu den Zutaten dieses Kuchens (die einzige Business-Methode).
   * Hier werden die relevanten Felder der Zutat bergeben, die Bean setzt selbst die Kuchen-Id.
   * @param str_ZutatName Name der Zutat.
   * @param str_Menge Erforderliche Menge
   * @return Die erzeugte Zutat.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalZutatBMP addZutat (String str_ZutatName, String str_Menge);
}