package com.knauf.ejb.kuchenzutatbmp;

import javax.ejb.EJBLocalObject;

/**
 * Local-Interface der Kuchen-Zutat, Bean-Managed-Persistence-Variante.
 * Darf kein Remote-Interface sein, da in beide Richtungen (von Kuchen zu Zutat und
 * von Zutat zu Kuchen) referenziert werden kann.
 * 
 * @author  Wolfgang Knauf
 * @version 1.0
 */

public interface LocalZutatBMP extends EJBLocalObject
{
  /**Abrufen der Zutat-ID.
   * Es gibt keine Set-Methode dazu (weil es das PrimaryKey-Feld ist).
   * @return Die Zutat-ID.
   */
  public Long getId();

  /**Abrufen des Zutat-Namens.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public String getZutatName();

  /**Setzen des Zutat-Namens.
   * @param str_Name Neuer Name.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public void setZutatName (String str_Name);

  /**Abrufen der Menge (als String)
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public String getMenge();

  /**Setzen der menge als String
   * @param str_Menge Neue Menge
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public void setMenge (String str_Menge);

  /**Abrufen der Kuchen-ID
   * @return Die Kuchen-ID.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public Long getKuchenId();

  /**Setzen der Kuchen-ID. Darf hier nicht abstrakt sein.
   * @param lng_KuchenId Die Kuchen-ID
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public void setKuchenId (Long lng_KuchenId);


  /**Abrufen des Kuchens, zu dem die Zutat gehrt.
   * @return Der Kuchen der Zutat.
   */
  public LocalKuchenBMP getKuchen();
}